@@ -46,7 +46,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
-            _log_operation(module, 'add', result[0], req_log_data, res_log_data)
+            log_operation(module, 'add', result[0], req_log_data, res_log_data)
             flaskz_logger.info(get_rest_log_msg('Add {} data'.format(class_name), req_log_data, result[0], res_log_data))
 
             return create_response(result[0], res_data)
@@ -64,13 +64,13 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
-            _log_operation(module, 'delete', result[0], did, res_log_data)
+            log_operation(module, 'delete', result[0], did, res_log_data)
             flaskz_logger.info(get_rest_log_msg('Delete {} data'.format(class_name), did, result[0], res_log_data))
 
             return create_response(result[0], res_data)
 
     if 'update' in routers:
-        @api_blueprint.route(url_prefix + '/', methods=['PUT', 'PATCH'])
+        @api_blueprint.route(url_prefix + '/', methods=['PATCH'])
         @rest_permission_required(module, 'update')
         @gen_route_method('update', url_prefix)
         def update():
@@ -85,13 +85,24 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
-            _log_operation(module, 'update', result[0], req_log_data, res_log_data)
+            log_operation(module, 'update', result[0], req_log_data, res_log_data)
             flaskz_logger.info(get_rest_log_msg('Update {} data'.format(class_name), req_log_data, result[0], res_log_data))
 
             return create_response(result[0], res_data)
 
+    # if 'update' in routers:
+    #     @api_blueprint.route(url_prefix + '/', methods=['PUT'])
+    #     @rest_permission_required(module, 'update')
+    #     @gen_route_method('update_put', url_prefix)
+    #     def update():
+    #         """
+    #         todo
+    #         Update the model data by the json in put mode.
+    #         The difference between put and patch is that patch is partial update, and put is full update.            """
+    #         pass
+
     if 'upsert' in routers:
-        @api_blueprint.route(url_prefix + '/upsert/', methods=['PUT', 'PATCH'])
+        @api_blueprint.route(url_prefix + '/upsert/', methods=['POST'])
         @rest_permission_required(module, 'upsert')
         @gen_route_method('upsert', url_prefix)
         def update():
@@ -111,7 +122,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
 
             res_data = model_to_dict(result[1], to_json_option)
             res_log_data = get_log_data(res_data)
-            _log_operation(module, action, result[0], req_log_data, res_log_data)
+            log_operation(module, action, result[0], req_log_data, res_log_data)
             flaskz_logger.info(get_rest_log_msg('Upsert {} data'.format(class_name), req_log_data, result[0], res_log_data))
 
             return create_response(result[0], res_data)
@@ -203,10 +214,10 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
     return api_blueprint
 
 
-def _log_operation(*args, **kwargs):
-    logging_callback = get_current_model_rest_manager_callback('logging_callback')
-    if logging_callback:
-        logging_callback(*args, **kwargs)
+# def _log_operation(*args, **kwargs):
+#     logging_callback = get_current_model_rest_manager_callback('logging_callback')
+#     if logging_callback:
+#         logging_callback(*args, **kwargs)
 
 
 from ._mgmt import *
